@@ -477,7 +477,7 @@ void QuickDocument::readDocumentClassConfig()
 	// set encoding combobox
 	fillCombobox(m_cbEncoding,
 	             "ansinew,applemac,ascii,cp1252,cp1250,cp1251,cp1257,cp437,cp437de,cp850,cp858,"
-	             "cp852,cp865,decmulti,koi8-r,latin1,latin2,latin3,latin4,latin5,latin9,latin10,next,utf8x,utfcyr",
+	             "cp852,cp865,decmulti,koi8-r,latin1,latin2,latin3,latin4,latin5,latin9,latin10,next,utf8,utf8x,utfcyr",
 	             m_currentEncoding);
 }
 
@@ -1635,7 +1635,7 @@ void QuickDocument::printBeamerTheme()
 	if (reg.indexIn(theme) >= 0) {
 		QStringList optionlist = reg.cap(2).split(',');
 		m_td.tagBegin += "\\usepackage[" + optionlist.join(",") + "]{beamertheme" + reg.cap(1) + "}\n\n";
-	} 
+	}
 	else {
 		m_td.tagBegin += "\\usepackage{beamertheme" + theme + "}\n\n";
 	}
@@ -1648,21 +1648,21 @@ void QuickDocument::slotButtonClicked(int button)
 	KILE_DEBUG() << "called";
 
 	if (button == KDialog::Ok){
-	
+
 		// get current class options
 		m_currentClass = m_cbDocumentClass->currentText();
 		KILE_DEBUG() << "current class: " << m_currentClass;
-	
+
 		// save the checked options
 		m_dictDocumentClasses[m_currentClass][qd_SelectedOptions] = getClassOptions();
 		KILE_DEBUG() << "save options: " << m_dictDocumentClasses[m_currentClass][qd_SelectedOptions];
-	
+
 		// build template
 		printTemplate();
-	
+
 		// update config file
 		writeConfig();
-	
+
 		accept();
 	}
 	else{
@@ -1670,7 +1670,7 @@ void QuickDocument::slotButtonClicked(int button)
 	}
 }
 
-////////////////////////////// slots: document class 
+////////////////////////////// slots: document class
 void QuickDocument::slotDocumentClassAdd()
 {
 	KILE_DEBUG() << "==QuickDocument::slotDocumentClassAdd()============";
@@ -1715,7 +1715,7 @@ void QuickDocument::slotDocumentClassAdd()
 		m_dictDocumentClasses[classname] = classlist;
 
 		fillDocumentClassCombobox();
-		
+
 		// add the new document class into the userClasslist and the documentClass-combobox
 		m_userClasslist.append(classname);
 
@@ -2314,44 +2314,44 @@ bool QuickDocumentInputDialog::checkListEntries(const QString &title, const QStr
 void QuickDocumentInputDialog::slotButtonClicked(int button)
 {
 	if(button == KDialog::Ok){
-	
+
 		if (m_check) {
 			// get the label and main input string from the first label/linedit
 			QString inputlabel = ((QLabel *)m_objectlist[0])->text();
 			QString input = ((KLineEdit *)m_objectlist[1])->text().simplified();
-	
+
 			// should we check for an empty string
 			if ((m_check & qd_CheckNotEmpty) && input.isEmpty()) {
 				KMessageBox::error(this, i18n("An empty string is not allowed."));
 				return;
 			}
-	
+
 			// should we check for an existing document class
 			if (m_check & qd_CheckDocumentClass) {
 				if (m_parent->isDocumentClass(input)) {
 					KMessageBox::error(this, i18n("This document class already exists."));
 					return;
 				}
-	
+
 				QRegExp reg("\\w+");
 				if (!reg.exactMatch(input)) {
 					KMessageBox::error(this, i18n("This name is not allowed for a document class."));
 					return;
 				}
 			}
-	
+
 			// should we check for an existing document class option
 			if ((m_check & qd_CheckClassOption) && m_parent->isDocumentClassOption(input)) {
 				KMessageBox::error(this, i18n("This document class option already exists."));
 				return;
 			}
-	
+
 			// should we check for an existing package
 			if ((m_check & qd_CheckPackage) && m_parent->isPackage(input)) {
 				KMessageBox::error(this, i18n("This package already exists."));
 				return;
 			}
-	
+
 			// should we check for an existing package option
 			if (m_check & qd_CheckPackageOption) {
 				QString package = getPackageName(inputlabel);
@@ -2364,12 +2364,12 @@ void QuickDocumentInputDialog::slotButtonClicked(int button)
 					return;
 				}
 			}
-	
+
 			// should we check for a (list of) fontsizes
 			if ((m_check & qd_CheckFontsize) && !checkListEntries("Fontsize", input, "\\d+pt")) {
 				return;
 			}
-	
+
 			// should we check for a (list of) papersizes
 			if ((m_check & qd_CheckPapersize) && !checkListEntries("Papersize", input, "\\w+")) {
 				return;
