@@ -1,7 +1,7 @@
 /***************************************************************************************
     begin                : sam jui 13 09:50:06 CEST 2002
     copyright            : (C) 2003 by Jeroen Wijnhout (wijnhout@science.uva.nl)
-                               2007-2011 by Michel Ludwig (michel.ludwig@kdemail.net)
+                               2007-2012 by Michel Ludwig (michel.ludwig@kdemail.net)
                            (C) 2009 Thomas Braun (thomas.braun@virtuell-zuhause.de)
 
  ***************************************************************************************/
@@ -174,7 +174,7 @@ private:
 	/* config */
 	KSharedConfigPtr	m_config;
 	int 			m_horSplitRight, m_horSplitLeft, m_verSplitTop, m_verSplitBottom;
-	QStringList 		m_recentFilesList, m_listDocsOpenOnStart, m_listProjectsOpenOnStart;
+	QStringList 		m_recentFilesList, m_listDocsOpenOnStart, m_listEncodingsOfDocsOpenOnStart, m_listProjectsOpenOnStart;
 
 	KRecentFilesAction *m_actRecentProjects;
 
